@@ -9,7 +9,7 @@ from kks.util.common import find_workspace, find_problem_rootdir, config_directo
 
 target_file = 'targets.yaml'
 
-targets_version = 2
+targets_version = 3
 
 global_comment = '# This is the default config file, it is used in any subdirectory of the workspace.\n'\
                  '# You can modify the default target (the changes will be applied only in this workspace).\n'\
@@ -24,16 +24,17 @@ class Target:
         self.flags = settings.get('flags')
         self.libs = settings.get('libs')
         self.asm64bit = settings.get('asm64bit')
+        self.default_asan = settings.get('default_asan')
         self.out = settings.get('out')
 
         # option is not set or the list contains "DEFAULT" as first item
         # if the list is empty, we shouldn't replace it (e.g. if this target excludes all libs)
         self.need_default = any(arr is None or (arr and arr[0] == 'DEFAULT') for arr in [self.files, self.flags, self.libs])\
-                            or self.compiler is None or self.out is None or self.asm64bit is None
+                            or self.compiler is None or self.out is None or self.asm64bit is None or self.default_asan is None
         # custom default target may still have some fields not set, so we will have to get them from a higher-level config (workspace root or package-provided)
 
     def __str__(self):
-        return f'Target("{self.name}", compiler="{self.compiler}", flags={self.flags}, files={self.files}, libs={self.libs}, asm64bit={self.asm64bit}, out="{self.out}")'
+        return f'Target("{self.name}", compiler="{self.compiler}", flags={self.flags}, files={self.files}, libs={self.libs}, asm64bit={self.asm64bit}, default_asan={self.default_asan}, out="{self.out}")'
 
     def replace_macros_add_missing(self, problem, default_target):
         def modify(x):
@@ -53,6 +54,7 @@ class Target:
         self.libs = modify_list(self.libs, default_target.libs)
         self.out = modify(self.out) if self.out is not None else default_target.out  # "or" doesn't work
         self.asm64bit = self.asm64bit if self.asm64bit is not None else default_target.asm64bit
+        self.default_asan = self.default_asan if self.default_asan  is not None else default_target.default_asan
 
 
 def _copy_default(dest):
